# abrechnung

[![GitHub Actions Status](https://github.com/SFTtech/abrechnung/actions/workflows/ci_testing.yaml/badge.svg)](https://github.com/SFTtech/abrechnung/actions/workflows/ci_testing.yaml)

The **Abrechnung** aims to be a fully fledged, fully featured solution for payment management and bookkeeping in groups.

* [documentation](https://abrechnung.readthedocs.io)

## Contributing

If there is that feature that you really want to see implemented, you found a bug or would like to help in some other 
way please head over to the [contributing](https://abrechnung.readthedocs.io/en/latest/contributing.html) page.


## Contact

If you have questions, suggestions, encounter any problem, please join our Matrix or IRC channel and ask!

```
#sfttech:matrix.org
irc.freenode.net #sfttech
```

Of course, create [issues](https://github.com/SFTtech/abrechnung/issues)
and [pull requests](https://github.com/SFTtech/abrechnung/pulls).

## License

Released under the **GNU Affero General Public License** version 3 or later, see [COPYING](COPYING)
and [LICENSE](LICENSE) for details.
